@@ -12,43 +12,40 @@ Visualization of Data Projection Methods
 ========================================
 """
 
-from mvpa.misc.data_generators import noisy_2d_fx
-from mvpa.mappers.pca import PCAMapper
-from mvpa.mappers.svd import SVDMapper
-from mvpa.mappers.ica import ICAMapper
-from mvpa import cfg
+from mvpa2.support.pylab import pl
+from mvpa2.misc.data_generators import noisy_2d_fx
+from mvpa2.mappers.svd import SVDMapper
+from mvpa2.mappers.mdp_adaptor import ICAMapper, PCAMapper
+from mvpa2 import cfg
 
-import pylab as P
-import numpy as N
 center = [10, 20]
 axis_range = 7
 
-def plotProjDir(mproj):
-    p = mproj + N.array(center).T
-
-    P.plot([center[0], p[0,0]], [center[1], p[0,1]], hold=True)
-    P.plot([center[0], p[1,0]], [center[1], p[1,1]], hold=True)
-
-
+##REF: Name was automagically refactored
+def plot_proj_dir(p):
+    pl.plot([0, p[0,0]], [0, p[0,1]],
+           linewidth=3, hold=True, color='y')
+    pl.plot([0, p[1,0]], [0, p[1,1]],
+           linewidth=3, hold=True, color='k')
 
 mappers = {
             'PCA': PCAMapper(),
             'SVD': SVDMapper(),
-            'ICA': ICAMapper(),
+            'ICA': ICAMapper(alg='CuBICA'),
           }
 datasets = [
     noisy_2d_fx(100, lambda x: x, [lambda x: x],
-                center, noise_std=.5),
+                center, noise_std=0.5),
     noisy_2d_fx(50, lambda x: x, [lambda x: x, lambda x: -x],
-                center, noise_std=.5),
+                center, noise_std=0.5),
     noisy_2d_fx(50, lambda x: x, [lambda x: x, lambda x: 0],
-                center, noise_std=.5),
+                center, noise_std=0.5),
    ]
 
 ndatasets = len(datasets)
 nmappers = len(mappers.keys())
 
-P.figure(figsize=(8,8))
+pl.figure(figsize=(8,8))
 fig = 1
 
 for ds in datasets:
@@ -57,22 +54,20 @@ for ds in datasets:
 
         dproj = mapper.forward(ds.samples)
         mproj = mapper.proj
-        print mproj
-
-        P.subplot(ndatasets, nmappers, fig)
+        pl.subplot(ndatasets, nmappers, fig)
         if fig <= 3:
-            P.title(mname)
-        P.axis('equal')
+            pl.title(mname)
+        pl.axis('equal')
 
-        P.scatter(ds.samples[:, 0],
-                  ds.samples[:, 1],
-                  s=30, c=(ds.labels) * 200)
-        plotProjDir(mproj)
+        pl.scatter(ds.samples[:, 0] - center[0],
+                  ds.samples[:, 1] - center[1],
+                  s=30, c=(ds.sa.targets) * 200)
+        plot_proj_dir(mproj)
         fig += 1
 
 
 if cfg.getboolean('examples', 'interactive', True):
-    P.show()
+    pl.show()
 
 """
 Output of the example:
