@@ -14,6 +14,7 @@ if __debug__:
 
 import numpy as np
 import os
+from os.path import join as pathjoin
 import sys
 
 from mvpa2.base import externals
@@ -26,10 +27,10 @@ if externals.exists('ctypes', raise_=True):
     if sys.platform == 'win32':
         # on windows things get tricky as we compile this lib as an extension
         # so it get a .pyd name suffix instead of .dll
-        smlrlib = C.cdll[os.path.join(os.path.dirname(__file__), 'smlrc.pyd')]
+        smlrlib = C.cdll[pathjoin(os.path.dirname(__file__), 'smlrc.pyd')]
     elif sys.platform == 'darwin':
         # look for .so extension on Mac (not .dylib this time)
-        smlrlib = C.cdll[os.path.join(os.path.dirname(__file__), 'smlrc.so')]
+        smlrlib = C.cdll[pathjoin(os.path.dirname(__file__), 'smlrc.so')]
     else:
         smlrlib = np.ctypeslib.load_library('smlrc', os.path.dirname(__file__))
 
