@@ -21,7 +21,7 @@ from mvpa2.base import warning
 
 
 def _prefix(prefix, val):
-    if isinstance(val, int):
+    if isinstance(val, (np.integer, int)):
         return '%s%.3i' % (prefix, val)
     else:
         return '%s%s' % (prefix, val)
@@ -64,20 +64,22 @@ def _get_description_dict(path, xfm_key=None):
         for line in open(path, 'r'):
             key = line.split()[0]
             value = line[len(key):].strip()
-            if not xfm_key is None:
+            if xfm_key is not None:
                 key = xfm_key(key)
             props[key] = value
     return props
 
 
 def _subdirs2ids(path, prefix, **kwargs):
-    ids = []
+    # num_ids to separate sorting of numeric and literal ids
+    ids, num_ids = [], []
     if not os.path.exists(path):
         return ids
     for item in os.listdir(path):
         if item.startswith(prefix) and os.path.isdir(_opj(path, item)):
-                ids.append(_id2int(item, **kwargs))
-    return sorted(ids)
+            id_ = _id2int(item, **kwargs)
+            (num_ids if isinstance(id_, (np.integer, int)) else ids).append(id_)
+    return sorted(num_ids) + sorted(ids)
 
 
 def _stripext(path):
@@ -225,7 +227,24 @@ class OpenFMRIDataset(object):
         else:
             flavor = '_' + flavor
         fname = 'bold%s.nii.gz' % flavor
-        return self._load_bold_task_run_data(subj, task, run, [fname], nb.load)
+        img = self._load_bold_task_run_data(subj, task, run, [fname], nb.load)
+        zooms = img.header.get_zooms()
+        if len(zooms) > 3:
+            tr = zooms[3]
+            if tr == 1.0:
+                # Many "original" OpenfMRI datasets have a bug of having degenerate
+                # TR=1.0, so let's check if it corresponds to the scan_key
+                # TODO: there is no lazy evaluation, so would reread file over and
+                # over again.  At least should be cheap
+                props = self.get_scan_properties()
+                prop_tr = float(props.get('TR', 1.0))
+                if prop_tr != tr:
+                    new_zooms = zooms[:3] + (prop_tr,) + zooms[4:]
+                    warning("Dataset file has time dimension set to 1.0 whenever "
+                            "scan_key.txt states it to be %.2f.  Setting zooms "
+                            "to %s" % (prop_tr, new_zooms))
+                    img.header.set_zooms(new_zooms)
+        return img
 
     def get_bold_run_motion_estimates(self, subj, task, run,
                                       fname='bold_moest.txt'):
@@ -371,15 +390,15 @@ class OpenFMRIDataset(object):
         from mvpa2.datasets.mri import fmri_dataset
 
         # check whether flavor corresponds to a particular file
-        if not flavor is None:
+        if flavor is not None:
             path = _opj(self.basedir, _sub2id(subj),
                         'BOLD', _taskrun(task, run), flavor)
-        if not flavor is None and os.path.exists(path):
+        if flavor is not None and os.path.exists(path):
             from mvpa2.base.hdf5 import h5load
             ds = h5load(path)
         else:
             bold_img = self.get_bold_run_image(subj, task, run, flavor=flavor)
-            if not preproc_img is None:
+            if preproc_img is not None:
                 bold_img = preproc_img(bold_img)
             # load (and mask) data
             ds = fmri_dataset(bold_img, **kwargs)
@@ -534,7 +553,8 @@ class OpenFMRIDataset(object):
             ev['onset_idx'] = i
         return events
 
-    def get_model_bold_dataset(self, model_id, subj_id, preproc_img=None,
+    def get_model_bold_dataset(self, model_id, subj_id, run_ids=None,
+                               preproc_img=None,
                                preproc_ds=None, modelfx=None, stack=True,
                                flavor=None, mask=None, add_fa=None,
                                add_sa=None, **kwargs):
@@ -548,6 +568,8 @@ class OpenFMRIDataset(object):
           Integer, or string ID of the subject whose data shall be considered.
           Alternatively, a list of IDs can be given and data from all matching
           subjects will be loaded at once.
+        run_ids : list, optional
+          Run ids to be loaded.  If None, all runs get loaded
         preproc_img : callable or None
           See get_bold_run_dataset() documentation
         preproc_ds : callable or None
@@ -589,7 +611,7 @@ class OpenFMRIDataset(object):
         conds = self.get_model_conditions(model_id)
         # what tasks do we need to consider for this model
         tasks = np.unique([c['task'] for c in conds])
-        if isinstance(subj_id, int) or isinstance(subj_id, basestring):
+        if isinstance(subj_id, (int, basestring)):
             subj_id = [subj_id]
         dss = []
         for sub in subj_id:
@@ -597,7 +619,10 @@ class OpenFMRIDataset(object):
             # what runs exists: that means we have to load the model info
             # repeatedly
             for task in tasks:
-                for i, run in enumerate(self.get_bold_run_ids(sub, task)):
+                run_ids_ = run_ids \
+                    if run_ids is not None \
+                    else self.get_bold_run_ids(sub, task)
+                for i, run in enumerate(run_ids_):
                     events = self.get_bold_run_model(model_id, sub, run)
                     # at this point our events should only contain those
                     # matching the current task. If not, this model violates
@@ -622,7 +647,7 @@ class OpenFMRIDataset(object):
                         sub, task, run=run, flavor=flavor,
                         preproc_img=preproc_img, chunks=i, mask=mask,
                         add_fa=add_fa, add_sa=add_sa)
-                    if not preproc_ds is None:
+                    if preproc_ds is not None:
                         d = preproc_ds(d)
                     d = modelfx(
                         d, events, **dict([(k, v) for k, v in kwargs.iteritems()
