@@ -24,6 +24,12 @@ import mvpa2
 from mvpa2.base import externals, warning
 from mvpa2.base.dochelpers import strip_strid
 
+import platform
+platform_system = platform.system().lower()
+on_windows = platform_system == 'windows'
+on_osx = platform_system == 'darwin'
+on_linux = platform_system == 'linux'
+
 if __debug__:
     from mvpa2.base import debug
 
@@ -101,17 +107,22 @@ def assert_collections_equal(x, y, ignore=None):
     if ignore is None:
         ignore = {}
     from mvpa2.base.node import Node
+    from mvpa2.base.collections import Collectable
 
     assert_dict_keys_equal(x, y)
     for k in x.keys():
-        v1, v2 = x[k].value, y[k].value
+        v1, v2 = x[k], y[k]
         assert_equal(type(v1), type(v2),
                      msg="Values for key %s have different types: %s and %s"
                          % (k, type(v1), type(v2)))
+        if isinstance(v1, Collectable):
+            v1, v2 = v1.value, v2.value
         if k in ignore:
             continue
         if isinstance(v1, np.ndarray):
             assert_array_equal(v1, v2)
+        elif isinstance(v1, dict):
+            assert_collections_equal(v1, v2)
         elif isinstance(v1, Node) and not (
                 hasattr(v1, '__cmp__')
                 or (hasattr(v1, '__eq__') and v1.__class__.__eq__ is not object.__eq__)):
