@@ -8,7 +8,7 @@
 ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
 """Unit tests for PyMVPA MEG stuff"""
 
-import os.path
+from os.path import join as pathjoin
 
 from mvpa2.testing import *
 from mvpa2 import pymvpa_dataroot
@@ -22,7 +22,7 @@ class MEGTests(unittest.TestCase):
         if not externals.exists('gzip'):
             return
 
-        meg = TuebingenMEG(os.path.join(pymvpa_dataroot, 'tueb_meg.dat.gz'))
+        meg = TuebingenMEG(pathjoin(pymvpa_dataroot, 'tueb_meg.dat.gz'))
 
         # check basics
         self.assertTrue(meg.channelids == ['BG1', 'MLC11', 'EEG02'])
@@ -36,10 +36,11 @@ class MEGTests(unittest.TestCase):
         self.assertTrue(meg.data[3, 0, 808] == -4.30692876e-12)
 
 
-def suite():
+def suite():  # pragma: no cover
     return unittest.makeSuite(MEGTests)
 
 
-if __name__ == '__main__':
+if __name__ == '__main__':  # pragma: no cover
     import runner
+    runner.run()
 
