@@ -128,7 +128,7 @@ class RegressionsTests(unittest.TestCase):
     # conditioned that test_regressions was ran.  I could not spot
     # anything "stateful" on our Python side, and I guess it is
     # a problem of R's implementation
-    @sweepargs(regr=regrswh['regression', 'has_sensitivity', '!gpr'])
+    @sweepargs(regr=regrswh['regression', 'has_sensitivity', '!gpr', '!lars'])
     @reseed_rng()
     def test_sensitivities(self, regr):
         """Test "sensitivities" provided by regressions
@@ -151,9 +151,10 @@ class RegressionsTests(unittest.TestCase):
         # TODO: extend the test -- checking for validity of sensitivities etc
 
 
-def suite():
+def suite():  # pragma: no cover
     return unittest.makeSuite(RegressionsTests)
 
 
-if __name__ == '__main__':
+if __name__ == '__main__':  # pragma: no cover
     import runner
+    runner.run()
