@@ -33,6 +33,8 @@ from mvpa2.clfs.transerror import ConfusionBasedError
 from mvpa2.misc.attrmap import AttributeMap
 from mvpa2.clfs.stats import MCNullDist
 from mvpa2.measures.base import ProxyMeasure, CrossValidation
+from mvpa2.measures.anova import OneWayAnova
+from mvpa2.measures.fx import targets_dcorrcoef
 
 from mvpa2.base.state import UnknownStateError
 
@@ -319,8 +321,8 @@ class RFETests(unittest.TestCase):
             # of normed sensitivities across those splits
             (RFE(rfesvm_split.get_sensitivity_analyzer(
                     postproc=ChainMapper([ FxMapper('features', l2_normed),
-                                           FxMapper('samples', np.mean),
-                                           FxMapper('samples', np.abs)])),
+                                           FxMapper('samples', np.abs),
+                                           FxMapper('samples', np.mean)])),
                  ConfusionBasedError(rfesvm_split, confusion_state='stats'),
                  Repeater(2),             #  we will use the same full cv-training dataset
                  fselector=FractionTailSelector(
@@ -515,7 +517,13 @@ class RFETests(unittest.TestCase):
 
     @reseed_rng()
     @labile(3, 1)
-    def test_SplitRFE(self):
+    # Let's test with clf sens analyzer AND OneWayAnova
+    @sweepargs(fmeasure=(None,  # use clf's sensitivity analyzer
+                         OneWayAnova(), # ad-hoc feature-wise measure
+                         # targets_mutualinfo_kde(), # FxMeasure
+                         targets_dcorrcoef(), # FxMeasure wrapper
+               ))
+    def test_SplitRFE(self, fmeasure):
         # just a smoke test ATM
         from mvpa2.clfs.svm import LinearCSVMC
         from mvpa2.clfs.meta import MappedClassifier
@@ -528,19 +536,22 @@ class RFETests(unittest.TestCase):
         from mvpa2.testing import ok_, assert_equal
 
         clf = LinearCSVMC(C=1)
-        dataset = normal_feature_dataset(perlabel=20, nlabels=2, nfeatures=30,
-                                         snr=1., nonbogus_features=[1,5])
+        dataset = normal_feature_dataset(perlabel=20, nlabels=2, nfeatures=11,
+                                         snr=1., nonbogus_features=[1, 5])
         # flip one of the meaningful features around to see
         # if we are still getting proper selection
         dataset.samples[:, dataset.a.nonbogus_features[1]] *= -1
-        # 4 partitions should be enough for testing
-        partitioner = NFoldPartitioner(count=4)
+        # 3 partitions should be enough for testing
+        partitioner = NFoldPartitioner(count=3)
 
         rfeclf = MappedClassifier(
             clf, SplitRFE(clf,
                           partitioner,
                           fselector=FractionTailSelector(
-                              0.2, mode='discard', tail='lower')))
+                              0.5, mode='discard', tail='lower'),
+                          fmeasure=fmeasure,
+                           # need to update only when using clf's sens anal
+                          update_sensitivity=fmeasure is None))
         r0 = repr(rfeclf)
 
         ok_(rfeclf.mapper.nfeatures_min == 0)
@@ -551,6 +562,7 @@ class RFETests(unittest.TestCase):
         # at least 1 of the nonbogus-features should be chosen
         ok_(len(set(dataset.a.nonbogus_features).intersection(
                 rfeclf.mapper.slicearg)) > 0)
+
         # check repr to have all needed pieces
         r = repr(rfeclf)
         s = str(rfeclf)
@@ -560,6 +572,33 @@ class RFETests(unittest.TestCase):
         ok_(not 'slicearg=' in r)
         assert_equal(r, r0)
 
+        if externals.exists('joblib'):
+            rfeclf.mapper.nproc = -1
+            # compare results against the one ran in parallel
+            _slicearg = rfeclf.mapper.slicearg
+            _predictions = predictions
+            rfeclf.train(dataset)
+            predictions = rfeclf(dataset).samples
+            assert_array_equal(predictions, _predictions)
+            assert_array_equal(_slicearg, rfeclf.mapper.slicearg)
+
+        # Test that we can collect stats from cas within cross-validation
+        sensitivities = []
+        nested_errors = []
+        nested_nfeatures = []
+        def store_me(data, node, result):
+            sens = node.measure.get_sensitivity_analyzer(force_train=False)(data)
+            sensitivities.append(sens)
+            nested_errors.append(node.measure.mapper.ca.nested_errors)
+            nested_nfeatures.append(node.measure.mapper.ca.nested_nfeatures)
+        cv = CrossValidation(rfeclf, NFoldPartitioner(count=1), callback=store_me,
+                             enable_ca=['stats'])
+        _ = cv(dataset)
+        # just to make sure we collected them
+        assert_equal(len(sensitivities), 1)
+        assert_equal(len(nested_errors), 1)
+        assert_equal(len(nested_nfeatures), 1)
+
 def suite():  # pragma: no cover
     return unittest.makeSuite(RFETests)
 
