@@ -11,15 +11,14 @@
 from mvpa2.testing import *
 skip_if_no_external('scipy')
 
-from mvpa2.testing.datasets import datasets
+from scipy.stats import f_oneway
 from mvpa2.tests.test_stats import *
 
-from scipy import signal
 from mvpa2.clfs.stats import match_distribution, rv_semifrozen
-from mvpa2.misc.stats import chisquare
+from mvpa2.misc.stats import chisquare, binomial_proportion_ci
 from mvpa2.misc.attrmap import AttributeMap
-from mvpa2.datasets.base import dataset_wizard
 from mvpa2.generators.permutation import AttributePermutator
+from mvpa2.misc.data_generators import simple_hrf_dataset
 
 class StatsTestsScipy(unittest.TestCase):
     """Unittests for various statistics which use scipy"""
@@ -30,8 +29,8 @@ class StatsTestsScipy(unittest.TestCase):
         # test equal distribution
         tbl = np.array([[5, 5], [5, 5]])
         chi, p = chisquare(tbl, exp=exp)
-        self.assertTrue( chi == 0.0 )
-        self.assertTrue( p == 1.0 )
+        self.assertTrue(chi == 0.0)
+        self.assertTrue(p == 1.0)
 
         # test perfect "generalization"
         tbl = np.array([[4, 0], [0, 4]])
@@ -76,8 +75,8 @@ class StatsTestsScipy(unittest.TestCase):
 
         # 100 and -100 should both have zero probability on their respective
         # tails
-        pm100 = null.p([-100] + [0]*(ds.nfeatures-1))
-        p100 = null.p([100] + [0]*(ds.nfeatures-1))
+        pm100 = null.p([-100] + [0] * (ds.nfeatures - 1))
+        p100 = null.p([100] + [0] * (ds.nfeatures - 1))
         assert_array_almost_equal(pm100, p100)
 
         # With 20 samples it isn't that easy to get a reliable sampling for
@@ -198,7 +197,7 @@ class StatsTestsScipy(unittest.TestCase):
                 # some really basic testing
                 matched = match_distribution(
                     data=data,
-                    distributions = ['scipy',
+                    distributions=['scipy',
                                      ('norm',
                                       {'name': 'norm_fixed',
                                        'loc': 0.2,
@@ -232,7 +231,7 @@ class StatsTestsScipy(unittest.TestCase):
                                          'uniform',
                                          ('uniform', {'loc': 0})
                                          ],
-                                     p=-1 # so we get all matches
+                                     p= -1 # so we get all matches
                                      )
         self.assertEqual(len(matches), 2) # we must get some match
 
@@ -241,21 +240,21 @@ class StatsTestsScipy(unittest.TestCase):
 
         if externals.versions['scipy'] >= '0.10':
             # known to work on 0.10 and fail on 0.7.3
-            self.assertTrue(abs(matches[0][-1][1]-9) < 1e-1) # full fit should get close to true scale
+            self.assertTrue(abs(matches[0][-1][1] - 9) < 1e-1) # full fit should get close to true scale
         else:
             raise SkipTest("KnownFailure to fit uniform on older scipy")
 
         # actually it fails ATM to fit uniform with frozen loc=0
         # nicely -- sets scale = 1 :-/   TODO
         raise SkipTest("TODO: Known failure to fit uniform with frozen loc")
-        self.assertTrue(abs(matches[1][-1][1]-9) < 1e-1) # frozen fit of scale
+        self.assertTrue(abs(matches[1][-1][1] - 9) < 1e-1) # frozen fit of scale
 
     def test_r_dist_stability(self):
         """Test either rdist distribution performs nicely
         """
         try:
             # actually I haven't managed to cause this error
-            scipy.stats.rdist(1.32, 0, 1).pdf(-1.0+np.finfo(float).eps)
+            scipy.stats.rdist(1.32, 0, 1).pdf(-1.0 + np.finfo(float).eps)
         except Exception, e:
             self.fail('Failed to compute rdist.pdf due to numeric'
                       ' loss of precision. Exception was %s' % e)
@@ -278,7 +277,7 @@ class StatsTestsScipy(unittest.TestCase):
             # NB: very cool way to store the trace of the execution
             #import pydb
             #pydb.debugger(dbg_cmds=['bt', 'l', 's']*300 + ['c'])
-            scipy.stats.rdist(1.32, 0, 1).cdf(-1.0+np.finfo(float).eps)
+            scipy.stats.rdist(1.32, 0, 1).cdf(-1.0 + np.finfo(float).eps)
         except IndexError, e:
             self.fail('Failed due to bug which leads to InvalidIndex if only'
                       ' scalar is provided to cdf')
@@ -287,12 +286,12 @@ class StatsTestsScipy(unittest.TestCase):
                       ' loss of precision. Exception was %s' % e)
 
         v = scipy.stats.rdist(10000, 0, 1).cdf([-0.1])
-        self.assertTrue(v>=0, v<=1)
+        self.assertTrue(v >= 0, v <= 1)
 
     @reseed_rng()
     def test_scipy_fit_2fparams(self):
         # fixing parameters was not before this version
-        skip_if_no_external('scipy', min_version='0.8.0')
+        skip_if_no_external('scipy', min_version='0.8.1')
         t = scipy.stats.t
         d = t(10, 1, 10).rvs(10)
         params = t.fit(d, floc=1, fscale=10.)
@@ -322,38 +321,9 @@ class StatsTestsScipy(unittest.TestCase):
         """
         skip_if_no_external('statsmodels')
         from mvpa2.measures.statsmodels_adaptor import GLM
-        # play fmri
-        # full-blown HRF with initial dip and undershoot ;-)
-        hrf_x = np.linspace(0, 25, 250)
-        hrf = double_gamma_hrf(hrf_x) - single_gamma_hrf(hrf_x, 0.8, 1, 0.05)
-
-        # come up with an experimental design
-        samples = 1800
-        fast_er_onsets = np.array([10, 200, 250, 500, 600, 900, 920, 1400])
-        fast_er = np.zeros(samples)
-        fast_er[fast_er_onsets] = 1
-
-        # high resolution model of the convolved regressor
-        model_hr = np.convolve(fast_er, hrf)[:samples]
-
-        # downsample the regressor to fMRI resolution
-        tr = 2.0
-        model_lr = signal.resample(model_hr,
-                                   int(samples / tr / 10),
-                                   window='ham')
-
-        # generate artifical fMRI data: two voxels one is noise, one has
-        # something
-        baseline = 800.0
-        wsignal = baseline + 2 * model_lr + \
-                  np.random.randn(int(samples / tr / 10)) * 0.2
-        nsignal = baseline + np.random.randn(int(samples / tr / 10)) * 0.5
-
-        # build design matrix: bold-regressor and constant
-        X = np.array([model_lr, np.repeat(1, len(model_lr))]).T
-
-        # two 'voxel' dataset
-        data = dataset_wizard(samples=np.array((wsignal, nsignal, nsignal)).T, targets=1)
+        # high SNR dataset for such a short timeseries
+        data = simple_hrf_dataset(signal_level=2, noise_level=0.5)
+        X = data.sa.design
 
         # check GLM betas
         glm = GLM(X)
@@ -362,16 +332,15 @@ class StatsTestsScipy(unittest.TestCase):
         # betas for each feature and each regressor
         self.assertTrue(betas.shape == (X.shape[1], data.nfeatures))
 
-        self.assertTrue(np.absolute(betas.samples[1] - baseline < 10).all(),
+        self.assertTrue(np.absolute(betas.samples[1] - data.a.baseline < 10).all(),
             msg="baseline betas should be huge and around 800")
 
-        self.assertTrue(betas.samples[0,0] > betas[0,1],
+        self.assertTrue(betas.samples[0, 0] > betas[0, 1],
             msg="feature (with signal) beta should be larger than for noise")
 
         if cfg.getboolean('tests', 'labile', default='yes'):
-            self.assertTrue(np.absolute(betas[0,1]) < 0.5)
-            self.assertTrue(np.absolute(betas[0,0]) > 1.0)
-
+            self.assertTrue(np.absolute(betas[0, 1]) < 0.5)
+            self.assertTrue(np.absolute(betas[0, 0]) > 1.0)
 
         # check GLM t values
         glm = GLM(X, voi='tvalues')
@@ -383,7 +352,7 @@ class StatsTestsScipy(unittest.TestCase):
                 msg='constant tvalues should be huge')
 
         if cfg.getboolean('tests', 'labile', default='yes'):
-            self.assertTrue(np.absolute(betas[0,0]) > betas[0,1],
+            self.assertTrue(np.absolute(betas[0, 0]) > betas[0, 1],
                 msg='with signal should have higher tvalues')
 
         # check t-contrast -- should do the same as tvalues for the first
@@ -391,17 +360,17 @@ class StatsTestsScipy(unittest.TestCase):
         glm = GLM(X, voi=[1, 0])
         contrast = glm(data)
         assert_array_almost_equal(contrast.samples[0], tstats.samples[0])
-        assert_equals(len(contrast), 5)
+        assert_equals(len(contrast), 6)
         # we should be able to recover the approximate effect size of the signal
         # which is constructed with a baseline offset of 2 (see above)
         if cfg.getboolean('tests', 'labile', default='yes'):
-            assert_true(1.5 < contrast.samples[2,0] < 2.5)
+            assert_true(1.5 < contrast.samples[2, 0] < 2.5)
 
         # check F-test
         glm = GLM(X, voi=[[1, 0]])
         ftest = glm(data)
         assert_equals(len(ftest), 4)
-        assert_true(ftest.samples[0,0] > ftest.samples[0,1])
+        assert_true(ftest.samples[0, 0] > ftest.samples[0, 1])
 
 
     def test_binomdist_ppf(self):
@@ -422,11 +391,47 @@ class StatsTestsScipy(unittest.TestCase):
         #   test_transerror.py:ErrorsTests.test_confusionmatrix_nulldist
         pass
 
-def suite():
+def test_binomial_proportion_ci():
+    # compare to gold-standard values from the matlab implementation
+    from numpy import testing as npt
+    n = 100
+    X = 50
+    p = .05
+    matlab_truth = {
+        'wald': (.4020, .5980),
+        'wilson': (.4038, .5962),
+        'agresti-coull': (.4038, .5962),
+        'jeffreys': (.4032, .5968),
+        'clopper-pearson': (.3983, .6017),
+        'arc-sine': (.4026, .5974),
+        'logit': (.4032, .5968),
+        'anscombe': (.4037, .5963)
+    }
+    for m in matlab_truth.keys():
+        npt.assert_array_almost_equal(matlab_truth[m],
+                                      binomial_proportion_ci(n, X, p, m),
+                                      decimal=4,
+                                      err_msg=m)
+        # can deal with the extremes
+        # those two have numerical limits
+        if not m in ('clopper-pearson', 'logit'):
+            npt.assert_array_almost_equal(
+                    binomial_proportion_ci(1000, 1000, .05, m),
+                    [1, 1],
+                    decimal=2)
+            npt.assert_array_almost_equal(
+                    binomial_proportion_ci(1000, 0, .05, m),
+                    [0, 0],
+                    decimal=2)
+    vec = binomial_proportion_ci(1000, [600,100,900])
+    assert_equal(vec.shape, (2, 3))
+
+def suite():  # pragma: no cover
     """Create the suite"""
     return unittest.makeSuite(StatsTestsScipy)
 
 
-if __name__ == '__main__':
+if __name__ == '__main__':  # pragma: no cover
     import runner
+    runner.run()
 
