@@ -10,6 +10,7 @@
 
 import inspect
 import re
+import sys
 import unittest
 
 from mvpa2.base.dochelpers import get_docstring_split
@@ -21,15 +22,16 @@ class SuiteTest(unittest.TestCase):
         """
         try:
             exec "from mvpa2.suite import *"
-        except Exception, e:
-            self.fail(msg="Cannot import everything from mvpa2.suite."
-                      "Getting %s" % e)
+        except Exception, e: # pragma: no cover - should not be hit if ok_
+            self.fail(msg="Cannot import everything from mvpa2.suite: %s" % e)
 
     def test_docstrings(self):
+        #import mvpa2.suite as mv
         from mvpa2.suite import suite_stats
         # Lets do compliance checks
         # Get gross information on what we have in general
-        gs = suite_stats()
+        #mv_scope = dict((x, getattr(mv, x)) for x in dir(mv))
+        gs = suite_stats()#mv_scope)
 
         # all functions/classes/types should have some docstring
         missing = []
@@ -39,14 +41,15 @@ class SuiteTest(unittest.TestCase):
         con_re2 = re.compile('(?::Parameters?:.*Parameters?\s*\n\s*-------'
                              '|Parameters?\s*\n\s*-------.*:Parameters?:)',
                              flags=re.DOTALL)
-        for c in ('classes', 'functions', 'modules', 'objects',
-                  'types'):
+        for c in ('functions', 'modules', 'objects', 'types') \
+          + ('classes',) if sys.version_info[0] < 3 else ():
             missing1 = []
             conflicting1 = []
+            self.assertTrue(gs[c])
             for k, i in gs[c].iteritems():
                 try:
                     s = i.__doc__.strip()
-                except:
+                except: # pragma: no cover - should not be hit if ok_
                     s = ""
                 if s == "":
                     missing1.append(k)
@@ -77,26 +80,27 @@ class SuiteTest(unittest.TestCase):
                 if si is not None \
                        and  con_re1.search(si) and con_re2.search(si):
                     conflicting1.append(k)
-            if len(missing1):
+            if len(missing1): # pragma: no cover - should not be hit if ok_
                 missing.append("%s: " % c + ', '.join(missing1))
-            if len(conflicting1):
+            if len(conflicting1): # pragma: no cover - should not be hit if ok_
                 conflicting.append("%s: " % c + ', '.join(conflicting1))
 
         sfailures = []
-        if len(missing):
+        if len(missing): # pragma: no cover - should not be hit if ok_
             sfailures += ["Some items have missing docstrings:\n "
                           + '\n '.join(missing)]
-        if len(conflicting):
+        if len(conflicting): # pragma: no cover - should not be hit if ok_
             sfailures += ["Some items have conflicting formats of docstrings:\n "
                       + '\n '.join(conflicting)]
-        if len(sfailures):
+        if len(sfailures): # pragma: no cover - should not be hit if ok_
             self.fail('\n'.join(sfailures))
 
 
-def suite():
+def suite():  # pragma: no cover
     return unittest.makeSuite(SuiteTest)
 
 
-if __name__ == '__main__':
+if __name__ == '__main__':  # pragma: no cover
     import runner
+    runner.run()
 
