@@ -138,7 +138,7 @@ class SurfingSurfaceTests(unittest.TestCase):
     @staticmethod
     def set_nan_to_surface_vertices(s, nan_ratio=.05):
         # make some vertices NaN (as might be the case for flat surfaces)
-        nan_count = np.ceil(s.nvertices * nan_ratio)
+        nan_count = int(np.ceil(s.nvertices * nan_ratio))
         nan_vertices_ids = np.random.random_integers(s.nvertices,
                                                      size=(nan_count,)) - 1
         vertices_noisy = s.vertices + 0.
@@ -335,7 +335,7 @@ class SurfingSurfaceTests(unittest.TestCase):
                 t = vertices[trg, :]
 
                 delta = s - t
-                print s, t, delta
+                # print s, t, delta
                 return np.sum(delta ** 2) ** .5
 
             for i_face in s.faces:
@@ -348,7 +348,7 @@ class SurfingSurfaceTests(unittest.TestCase):
                     c[src] += 1
                     c[trg] += 1
 
-                    print i, src, trg, d(src, trg)
+                    # print i, src, trg, d(src, trg)
 
             assert_array_almost_equal(sd / c, s.average_node_edge_length)
 
