@@ -178,10 +178,11 @@ class VerboseOutputTest(unittest.TestCase):
 
         # TODO: More tests needed for debug output testing
 
-def suite():
+def suite():  # pragma: no cover
     return unittest.makeSuite(VerboseOutputTest)
 
 
-if __name__ == '__main__':
+if __name__ == '__main__':  # pragma: no cover
     import runner
+    runner.run()
 
